@@ -20,6 +20,10 @@ class dbNode():
     def getInt(self, hex):
         return int('0x' + hex.lower(), base=16)
 
+    def acquire(self):
+        tokens = self.path.joinpath('_lock').glob()
+        print(tokens)
+
     def getKeyID(self, identifier):
         if isinstance(identifier, int):
             return identifier if identifier in self.keys else None
@@ -45,6 +49,7 @@ class dbNode():
         files = [object for object in self.path.glob('key*') if object.is_file()]
         for file in files:
             self.keys.append(int('0x' + file.name[3:].lower(), base=16))
+        self.keys.sort()
 
         try:
             with open(self.path.joinpath('_keyNames'), 'r') as nameFile:
@@ -136,6 +141,7 @@ class dbNode():
         folders = [object for object in self.path.glob('node*') if object.is_dir()]
         for folder in folders:
             self.nodes.append(int('0x' + folder.name[4:].lower(), base=16))
+        self.nodes.sort()
 
         try:
             with open(self.path.joinpath('_nodeNames'), 'r') as nameFile:
@@ -198,6 +204,28 @@ class dbNode():
                 matchingKeys.append(key)
         return matchingKeys
 
+
+# Create a database with no keys or nodes at the specified path
+def initDB(path, force=False):
+    pathObj = pathlib.Path(path).expanduser().resolve()
+    print(pathObj)
+    # Clean out what may be there
+    if pathObj.exists():
+        if force:
+            if pathObj.is_dir():
+                shutil.rmtree(str(pathObj))     # Wipe it away
+            else:
+                pathObj.unlink()
+        else:
+            raise RuntimeError('The specified path points to an existing file or directory')
+
+    # Set up a dbNode
+    pathObj.mkdir()
+    pathObj.joinpath('_keyNames').touch()
+    pathObj.joinpath('_nodeNames').touch()
+    pathObj.joinpath('_lock').touch()
+
+
 def cli():
     nodes = [(None, '(no node)')]
     dbLoaded = False
@@ -208,13 +236,19 @@ def cli():
             return int(string)
         except:
             return str(string)
+
+    def command_create(path, force):
+        if force in ('yes', 'no', 'y', 'n'):
+            initDB(path, force in ('yes', 'y'))
+        else:
+            print('Invalid option for \'force\': "{}"'.format(force))
             
     def command_load(path):
         nonlocal dbLoaded
         nonlocal nodes
         if dbLoaded:
             raise Exception('Already have a database loaded')
-        nodes = [(dbNode(path), 'dbRoot')]
+        nodes = [(dbNode(path), pathlib.Path(path).name)]
         dbLoaded = True
 
     def command_unload():
@@ -277,10 +311,10 @@ def cli():
             raise Exception('No database loaded')
         print(nodes[-1][0].rmNode(getIdentifier(id)))
 
-    def command_node(id, name):
+    def command_node(id):
         if not dbLoaded:
             raise Exception('No database loaded')
-        nodes.append((nodes[-1][0].node(getIdentifier(id)), name))
+        nodes.append((nodes[-1][0].node(getIdentifier(id)), id))
 
     def command_dropNode():
         if not dbLoaded:
@@ -295,6 +329,7 @@ def cli():
         runFlag = False
 
     commands = {
+        'create': command_create,
         'load': command_load,
         'unload': command_unload,
         'keys': command_keys,
